@@ -1,7 +1,7 @@
 package Pod::Weaver::Section::Completion::PerinciCmdLine;
 
-our $DATE = '2015-04-01'; # DATE
-our $VERSION = '0.10'; # VERSION
+our $DATE = '2015-07-30'; # DATE
+our $VERSION = '0.11'; # VERSION
 
 use 5.010001;
 use Moose;
@@ -24,6 +24,9 @@ sub weave_section {
     } elsif (!$res->[2]) {
         $self->log_debug(["skipped file %s (not a Perinci::CmdLine script: %s)", $filename, $res->[3]{'func.reason'}]);
         return;
+    } elsif ($res->[3]{'func.is_inline'}) {
+        $self->log_debug(["skipped file %s (Perinci::CmdLine::Inline currently does not support completion)"]);
+        return;
     }
 
     (my $command_name = $filename) =~ s!.+/!!;
@@ -49,7 +52,7 @@ Pod::Weaver::Section::Completion::PerinciCmdLine - Add a COMPLETION section for
 
 =head1 VERSION
 
-This document describes version 0.10 of Pod::Weaver::Section::Completion::PerinciCmdLine (from Perl distribution Pod-Weaver-Section-Completion-PerinciCmdLine), released on 2015-04-01.
+This document describes version 0.11 of Pod::Weaver::Section::Completion::PerinciCmdLine (from Perl distribution Pod-Weaver-Section-Completion-PerinciCmdLine), released on 2015-07-30.
 
 =head1 SYNOPSIS
 
@@ -84,6 +87,7 @@ Please report any bugs or feature requests on the bugtracker website L<https://r
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
